<<<<<<< HEAD
# SC-VAR

An approach to interpreting disease-associated human variants using single-cell epigenomics


# What can sc-var do?

Identify risk genes, gene sets, and cells related to different stages and diseases. 

Infer cell types involved in complex traits and diseases using single-cell epigenomes AND does not rely on any other annotations and other Omics data. 


# How to install?

pip install sc-var

check https://pypi.org/project/sc-var/


## About


![sc_var](https://github.com/gefeiZ/sc_var/assets/116159260/9a37b915-641d-48d6-aa73-97c6f3684b41)




## Usage

Check Usage.ipynb for details

Data request: 

Single cell ATAC-seq data &
Peak co-accessibility Data &
GWAS data 

=======
An approach to interpreting disease-associated human variants using single-cell epigenomics

What can sv_var do?

Identify risk genes, gene sets, and cells related to different stages and diseases.

Infer cell types involved in complex traits and diseases using single-cell epigenomes AND does not rely on any other annotations and other Omics data.
>>>>>>> f4c797e... Git LFS commit
